package org.jivesoftware.smackx.ikey.element;

import org.jivesoftware.smack.packet.NamedElement;
import org.jivesoftware.smack.packet.XmlEnvironment;
import org.jivesoftware.smack.util.StringUtils;
import org.jivesoftware.smack.util.XmlStringBuilder;

public class SubordinateElement implements NamedElement {

    public static final String ELEMENT = "sub";
    public static final String ATTR_SUB_URI = "uri";
    public static final String ATTR_SUB_FINGERPRINT = "fingerprint";

    private final String subUri;
    private final String subFingerprint;

    public SubordinateElement(String subKeyItemUri, String subKeyFingerprint) {
        this.subUri = StringUtils.requireNotNullNorEmpty(subKeyItemUri, "uri MUST NOT be null nor empty.");
        this.subFingerprint = StringUtils.requireNotNullNorEmpty(subKeyFingerprint, "fingerprint MUST NOT be null nor empty.");
    }

    public String getUri() {
        return subUri;
    }

    public String getFingerprint() {
        return subFingerprint;
    }

    @Override
    public String getElementName() {
        return ELEMENT;
    }

    @Override
    public XmlStringBuilder toXML(XmlEnvironment xmlEnvironment) {
        XmlStringBuilder xml = new XmlStringBuilder(this)
                .attribute(ATTR_SUB_URI, getUri())
                .attribute(ATTR_SUB_FINGERPRINT, getFingerprint())
                .closeEmptyElement();
        return xml;
    }
}
